@@ -8,7 +8,7 @@
 
 
 #define TITLE "ARP/RARP"
-#define VERSION "1.3"
+#define VERSION "1.31"
 #define CODERS "Copyright (C) 1999, 2000, 2001 Mark Grimes <obecian@packetninja.net>"
 
 #include <stdio.h>
@@ -42,6 +42,8 @@ int             payload_s;	/* payload size */
 char           *device;		/* network device */
 int             link_type, pcap_offset, l3;
 
+char            errbuf[256];
+struct ether_addr *e;
 struct libnet_link_int *l2;
 
 int             verbose;	/* verbosity */
