@@ -11,7 +11,7 @@
 int
 main(int argc, char **argv)
 {
-   int             opt;
+   int             opt, i;
    char           *file = NULL;
    static int      fd = -1;
    char            buff[512];
@@ -67,12 +67,8 @@ main(int argc, char **argv)
 	    sscanf(optarg, "%02X:%02X:%02X:%02X:%02X:%02X", &enet_tmp[0],
 		   &enet_tmp[1], &enet_tmp[2], &enet_tmp[3], &enet_tmp[4],
 		   &enet_tmp[5]);
-	    enet_src[0] = (u_char) enet_tmp[0];
-	    enet_src[1] = (u_char) enet_tmp[1];
-	    enet_src[2] = (u_char) enet_tmp[2];
-	    enet_src[3] = (u_char) enet_tmp[3];
-	    enet_src[4] = (u_char) enet_tmp[4];
-	    enet_src[5] = (u_char) enet_tmp[5];
+      for (i=0; i<6; i++)
+      	enet_src[i] = (u_char) enet_tmp[i];
 	 }
 	 break;
       case 'M':
@@ -80,12 +76,8 @@ main(int argc, char **argv)
 	    sscanf(optarg, "%02X:%02X:%02X:%02X:%02X:%02X", &enet_tmp[0],
 		   &enet_tmp[1], &enet_tmp[2], &enet_tmp[3], &enet_tmp[4],
 		   &enet_tmp[5]);
-	    enet_dst[0] = (u_char) enet_tmp[0];
-	    enet_dst[1] = (u_char) enet_tmp[1];
-	    enet_dst[2] = (u_char) enet_tmp[2];
-	    enet_dst[3] = (u_char) enet_tmp[3];
-	    enet_dst[4] = (u_char) enet_tmp[4];
-	    enet_dst[5] = (u_char) enet_tmp[5];
+      for (i=0; i<6; i++)
+      	enet_dst[i] = (u_char) enet_dst[i]; 
 	 }
 	 break;
       case 'i':
@@ -161,6 +153,15 @@ main(int argc, char **argv)
    if (verbose) {
       if (got_link) {
 	 printf("[MAC]  ");
+      if (enet_src[0] == NULL) {
+        e = libnet_get_hwaddr(l2, device, errbuf);
+        for (i=0; i<6; i++)
+          enet_src[i] = e->ether_addr_octet[i];
+        if (!e) {   
+          fprintf(stderr, "cannot retrieve hardware address of %s: %s\n", device, errbuf);
+          exit(1);
+        }
+      }
 	 printf("%02X:%02X:%02X:%02X:%02X:%02X > %02X:%02X:%02X:%02X:%02X:%02X\n", enet_src[0], enet_src[1], enet_src[2], enet_src[3], enet_src[4], enet_src[5], enet_dst[0], enet_dst[1], enet_dst[2], enet_dst[3], enet_dst[4], enet_dst[5]);
       }
       printf("[Ports] %d > %d\n", sport, dport);
